smartcard.CardMonitoring.CardMonitor

# ``smartcard`.`CardMonitoring`.`CardMonitor``

class documentation

`class CardMonitor(object):`

View In Hierarchy

Class that monitors smart card insertion / removals. and notify observers

note: a card monitoring thread will be running as long as the card monitor has observers, or CardMonitor.stop() is called. Do not forget to delete all your observers by calling `deleteObserver`, or your program will run forever...

Uses the singleton pattern from Thinking in Python Bruce Eckel, http://mindview.net/Books/TIPython to make sure there is only one `CardMonitor`.

Method | `__getattr__` | Undocumented
Method | `__init__` | Undocumented
Class Variable | `instance` | Undocumented
Class | `__CardMonitorSingleton` | The real smart card monitor class.

def __getattr__(self, name):

Undocumented

def __init__(self):

Undocumented

instance =

Undocumented